@@ -4,7 +4,7 @@
 
 ## quiets concerns of R CMD check re: the .'s that appear in pipelines
 if(getRversion() >= "2.15.1")  utils::globalVariables(c(".", "studyID", "agent", "dose", "Var1", "value",
-                                                        "Parameter", "fupdose", "groupvar", "y",
+                                                        "Parameter", "fupdose", "groupvar", "y", "sd", "standsd",
                                                         "network", "a", "param", "med", "l95", "u95", "value",
                                                         "Estimate", "2.5%", "50%", "97.5%", "treatment",
                                                         "study", "arm", "mod1.mean", "mod2.mean", "argcheck",
