@@ -580,9 +580,10 @@ check.indirect.drops <- function(df, comp) {
   for (study in seq_along(studies)) {
     subset <- df[df$studyID==studies[study],]
     if (all(comp %in% subset$treatment)) {
-      if (subset$narm[1]<=2) {
+      # if (subset$narm[1]<=2) {
+      if (dplyr::n_distinct(subset$treatment)<=2) {
         dropID <- append(dropID, subset$studyID[1])
-      } else if (subset$narm[1]>2) {
+      } else if (dplyr::n_distinct(subset$treatment)>2) {
         dropcomp <- append(dropcomp, subset$studyID[1])
       }
     }
@@ -676,12 +677,10 @@ check.indirect.drops <- function(df, comp) {
 #' summary(split) # Generate a data frame of summary results
 #' }
 #' @export
-mbnma.nodesplit <- function(network, fun=dloglin(),
+mbnma.nodesplit <- function(network, fun=dpoly(degree=1),
                             method="common",
                             comparisons=NULL,
                             incldr=TRUE,
-                            beta.1="rel", beta.2="rel", beta.3="rel", beta.4="rel",
-                            user.fun=NULL,
                             ...) {
 
   # Run checks
@@ -691,8 +690,6 @@ mbnma.nodesplit <- function(network, fun=dloglin(),
   checkmate::reportAssertions(argcheck)
 
   # Check fun
-  fun <- check.fun(fun=fun, network=network, beta.1=beta.1, beta.2=beta.2, beta.3=beta.3, beta.4=beta.4,
-                   user.fun=user.fun)
   if ("nonparam" %in% fun$name) {
     stop("Node-splitting cannot currently be performed for non-parametric models")
     # But this could be added
@@ -824,85 +821,186 @@ mbnma.nodesplit <- function(network, fun=dloglin(),
 
 
 
-#' Calculates relative effects between treatments in an MBNMA model
+#' Calculates league table of effects between treatments in MBNMA and/or NMA models
 #'
-#' @param mbnma An object of `class("mbnma")`
+#' @param lower.diag An S3 object either of class `"mbnma"` generated by running
+#'   a dose-response MBNMA model (using `mbnma.run()`), or of
+#'   class `"nma"` generated by running an NMA model (using `nma.run()`). Indicates that
+#'   this model should be used to estimate treatment effects in the **lower-left diagonal** of the league table.
+#' @param upper.diag Same as for `lower.diag`, but indicates that this model should be used
+#'   to estimate treatment effects in the **upper-right diagonal** of the league table.
 #' @param treatments A list whose elements each represent different treatments.
 #' Treatment is defined as a combination of agent and dose. Only agents specified in
-#' `mbnma` can be included. Each element in `treatments` is named corresponding to the
+#' `lower.diag` and `upper.diag` can be included. Each element in `treatments` is named corresponding to the
 #' agent and contains a numeric vector of doses. Relative effects will be calculated between
-#' all treatments specified in `treatments`. If `treatments` is left empty then the maximum
-#' dose for all agents in `mbnma` will be used as the default.
+#' all treatments specified in `treatments`. If `treatments` is left empty then the set of
+#' treatments in the network on which `lower.diag` is estimated will be used as the default.
+#' @param regress.vals A named numeric vector of effect modifier values at which relative effects
+#'   should be estimated. Named elements must match variable names specified in regression design matrix
+#'   (`mbnma$model.arg$regress.mat`), corresponding to variables in `regress` within
+#'   the MBNMA model (or **both** MBNMA models if different models are used for `upper.diag`
+#'   and `lower.diag`. Meta-regression is not currently possible for NMA models, so only
+#'   unadjusted results will be shown for these (and a warning given if they are compared to
+#'   adjusted MBNMA results).
+#' @param lower.direction Whether treatment effects should be presented as the column versus the row treatment
+#'   for each cell in the **lower-left diagonal** of the league table (`"colvrow"`) or as the row versus the
+#'   column treatment (`"rowvcol"`).
+#' @param upper.direction Same as for `upper.direction` but for results shown in the **upper-right diagonal** of
+#'   the league table.
 #' @param eform Whether outputted results should be presented in their exponential form (e.g. for
 #' models with log or logit link functions)
 #' @inheritParams predict.mbnma
 #'
 #'
 #' @return An array of `length(treatments) x length(treatments) x nsims`, where `nsims`
-#' is the number of iterations monitored in `mbnma`. The array contains the individual
+#' is the number of iterations monitored in `lower.diag`. The array contains the individual
 #' MCMC values for each relative effect calculated between all `treatments` on the link scale
-#' specified in the `mbnma` model. The direction of effect is for the row-defined treatment
-#' versus the column-defined
-#' treatment.
+#' specified in the `lower.diag` and `upper.diag` models.
 #'
 #'
 #' @examples
+#' \donttest{
+#'
 #' # Using the osteoarthritis data
 #' network <- mbnma.network(osteopain)
 #'
+#' # Run an MBNMA model
 #' expon <- mbnma.run(network, fun=dexp(), method="random")
 #'
-#' # Calculate relative effects between:
+#' # Calculate relative effects for MBNMA between:
 #' # Celebrex 100mg/d, Celebrex 200mg/d, Tramadol 100mg/d
-#' rel.eff <- get.relative(expon, treatments=list("Celebrex"=c(100,200), "Tramadol"=100))
+#' rel.eff <- get.relative(lower.diag=expon,
+#'   treatments=list("Celebrex"=c(100,200), "Tramadol"=100))
+#'
+#' # Run an NMA model
+#' nma <- nma.run(network, method="random")
+#'
+#' # Compare results between MBNMA and NMA models
+#' rel.eff <- get.relative(lower.diag=expon, upper.diag=nma,
+#'   treatments=list("Celebrex"=c(100,200), "Tramadol"=100),
+#'   upper.direction="colvrow")
+#' }
 #'
 #' @export
-get.relative <- function(mbnma, treatments=list(), eform=FALSE, lim="cred") {
+get.relative <- function(lower.diag, upper.diag=lower.diag, treatments=list(),
+                         lower.direction="colvrow", upper.direction="rowvcol",
+                         regress.vals=NULL,
+                         eform=FALSE, lim="cred") {
 
   # Run checks
   argcheck <- checkmate::makeAssertCollection()
-  checkmate::assertClass(mbnma, "mbnma", add=argcheck)
   checkmate::assertList(treatments, null.ok=FALSE, add=argcheck)
   checkmate::assertChoice(lim, choices=c("cred", "pred"), add=argcheck)
+  checkmate::assertChoice(lower.direction, choices=c("colvrow", "rowvcol"), add=argcheck)
+  checkmate::assertChoice(upper.direction, choices=c("colvrow", "rowvcol"), add=argcheck)
+  checkmate::assertNumeric(regress.vals, names = "named", null.ok=TRUE, add=argcheck)
   checkmate::reportAssertions(argcheck)
 
-  # Cannot use with UME
-  if (mbnma$model.arg$UME==TRUE) {
-    stop("get.relative() cannot be used on unrelated mean effects (UME=TRUE) models")
+  # Check classes
+  if (!any(class(lower.diag) %in% c("mbnma", "nma")) | !any(class(upper.diag) %in% c("mbnma", "nma"))) {
+    stop("lower.diag and upper.diag must have class 'mbnma' or 'nma'")
   }
 
-  # Cannot use with nonparam
-  if ("nonparam" %in% mbnma$model.arg$fun$name) {
-    stop("get.relative() cannot be used on non-parametric models")
+  if ("mbnma" %in% class(lower.diag)) {
+    lower.class <- "mbnma"
+  } else if ("nma" %in% class(lower.diag)) {
+    lower.class <- "nma"
   }
 
-  # Ensure prediction intervals are used where appropriate
-  if (lim=="pred" & mbnma$model.arg$method=="random") {
-    addsd <- TRUE
+  if ("mbnma" %in% class(upper.diag)) {
+    upper.class <- "mbnma"
+  } else if ("nma" %in% class(upper.diag)) {
+    upper.class <- "nma"
+  }
 
-    if (!"sd" %in% mbnma$parameters.to.save) {
-      stop(crayon::red("'sd' not included in parameters.to.save - cannot calculate prediction intervals"))
+  modlist <- list(lower.diag, upper.diag)
+  mbnma.ind <- which(sapply(modlist, function(x) {class(x)[1]}) %in% "mbnma")
+  nma.ind <- which(sapply(modlist, function(x) {class(x)[1]}) %in% "nma")
+
+  for (mod in seq_along(mbnma.ind)) {
+
+    # Cannot use with MBNMA UME
+    if (modlist[[mbnma.ind[mod]]]$model.arg$UME==TRUE) {
+      stop("get.relative() cannot be used on unrelated mean effects (UME=TRUE) MBNMA models")
     }
 
-  } else {
-    addsd <- FALSE
+    # Cannot use with nonparam
+    if ("nonparam" %in% modlist[[mbnma.ind[mod]]]$model.arg$fun$name) {
+      stop("get.relative() cannot be used on non-parametric MBNMA models")
+    }
+
+    # Ensure prediction intervals are used where appropriate with MBNMA
+    if (lim=="pred" & modlist[[mbnma.ind[mod]]]$model.arg$method=="random") {
+      addsd <- TRUE
+
+      if (!"sd" %in% modlist[[mbnma.ind[mod]]]$parameters.to.save) {
+        stop(crayon::red("'sd' not included in parameters.to.save - cannot calculate prediction intervals"))
+      }
+
+    } else {
+      addsd <- FALSE
+    }
   }
 
-  # If treatments is not specified use the max dose of each agent in the dataset
+  # For NMA models (if no MBNMA models present)
+  if (length(mbnma.ind)==0) {
+    if (lim=="pred") {
+      addsd <- TRUE
+    } else {
+      addsd <- FALSE
+    }
+  }
+
+  # If treatments is not specified use the treatments in the dataset for lower.diag
   if (length(treatments)==0) {
-    jagsdat <- mbnma$model.arg$jagsdata
-    for (i in seq_along(mbnma$network$agents)) {
-      treatments[[mbnma$network$agents[i]]] <- max(jagsdat$dose[jagsdat$agent==i], na.rm=TRUE)
+    if ("mbnma" %in% class(lower.diag)) {
+      treatments <- lower.diag$network$treatments
+    } else if ("nma" %in% class(lower.diag)) {
+      treatments <- lower.diag$trt.labs
+    }
+
+    agents <- gsub("(^.+)(_)(.+$)", "\\1", treatments)
+    doses <- gsub("(^.+)(_)(.+$)", "\\3", treatments)
+
+    treatments <- list()
+    for (i in seq_along(unique(agents))) {
+      treatments[[unique(agents)[i]]] <- as.numeric(doses[which(agents %in% unique(agents)[i])])
     }
   }
 
-  if (length(treatments)<2) {
-    if (length(treatments[[1]])<2) {
-      stop("`treatments` must have at least two elements to estimate relative\neffects between them")
+  if (length(unlist(treatments))<2) {
+    stop("`treatments` must include at least two agents/doses to estimate relative\neffects between them")
+  }
+
+  for (mod in seq_along(mbnma.ind)) {
+    if (!all(names(treatments) %in% modlist[[mbnma.ind[mod]]]$network$agents)) {
+      stop("names(treatments) are not all named agents in lower.diag or upper.diag\nget.relative() can only estimate MBNMA relative effects for agents included in MBNMA models")
     }
   }
-  if (!all(names(treatments) %in% mbnma$network$agents)) {
-    stop("names(treatments) are not all in mbnma$network$agents")
+
+  # If NMA model present
+  if (length(nma.ind)>0) {
+
+    treatments.nma <- vector()
+    for (i in seq_along(treatments)) {
+      for (k in seq_along(treatments[[i]])) {
+        treatments.nma <- append(treatments.nma, paste(names(treatments)[i], treatments[[i]][k], sep="_"))
+      }
+    }
+
+    for (mod in seq_along(nma.ind)) {
+
+      if (!all(names(treatments.nma) %in% modlist[[nma.ind[mod]]]$trt.labs)) {
+        stop("'treatments' are not all in named treatments in lower.diag or upper.diag\nget.relative() can only estimate NMA relative effects for treatments included in NMA models")
+      }
+    }
+
+    if (length(mbnma.ind)>0) {
+      if (!is.null(modlist[[mbnma.ind]]$model.arg$regress)) {
+        warning(paste0("MBNMA model incorporates meta-regression to account for effect modifiers,\n",
+                       "whilst NMA results will average across them. This may cause mismatches in results"))
+      }
+    }
   }
 
   # Change `placebo` to dose=0 of an agent
@@ -910,166 +1008,270 @@ get.relative <- function(mbnma, treatments=list(), eform=FALSE, lim="cred") {
     temptrts <- names(treatments)[names(treatments)!="Placebo"]
     treatments[[temptrts[1]]] <- c(0, treatments[[temptrts[1]]])
     treatments$Placebo <- NULL
-  }
 
-  # Identify dose-response function used in mbnma
-  DR <- suppressMessages(
-    write.dose.fun(fun=mbnma$model.arg$fun, effect="abs")[[1]])
-  DR <- gsub("(^.+<-)(.+)", "\\2", DR)
-  DR <- gsub("s\\.", "", DR) # Could remove if needed
-  if (length(mbnma$model.arg$fun$name)>1) {
-    DR <- DR[-1]
-  }
-
-
-  # Get dose-response parameter values
-  betaparams <- get.model.vals(mbnma)
-
-
-  trtnew <- treatments
-
-  # Generate spline basis matrix if required
-  splineopt <- c("rcs", "bs", "ns", "ls")
-  fun <- mbnma$model.arg$fun
-
-  # Get indices of non-placebo agents
-  index <- match(names(trtnew), mbnma$network$agents[!mbnma$network$agents %in% "Placebo"])
-
-  # If there are multiple DR functions
-  if ("posvec" %in% names(fun)) {
-    posvec <- fun$posvec
-
-    # Remove 1st element if Placebo in network
-    if ("Placebo" %in% mbnma$network$agents) {
-      posvec <- posvec[-1]
-    }
-  } else {
-    posvec <- rep(1, max(index))
-  }
-  for (i in seq_along(index)) {
-
-    if (fun$name[posvec[index[i]]] %in% splineopt) {
-      trtnew[[i]] <- genspline(trtnew[[i]],
-                               spline = fun$name[posvec[index[i]]],
-                               knots=fun$knots[[posvec[index[i]]]],
-                               degree = fun$degree[posvec[index[i]]],
-                               max.dose=max(mbnma$network$data.ab$dose[mbnma$network$data.ab$agent==which(names(trtnew)[i] == mbnma$network$agents)]))
+    # Reorder so placebo is at start
+    if (length(nma.ind)>0) {
+      treatments.nma <- c("Placebo_0", treatments.nma[-which(treatments.nma %in% "Placebo_0")])
     }
   }
 
-  # Create list of treatments with doses
-  trtlist <- list()
-  for (i in seq_along(trtnew)) {
-    if (is.matrix(trtnew[[i]])) { # Allows for splines
-      for (k in 1:nrow(trtnew[[i]])) {
-        trtlist[[length(trtlist)+1]] <- list(names(trtnew)[i], as.vector(trtnew[[i]][k,]))
-      }
-    } else {
-      for (k in seq_along(trtnew[[i]])) {
-        trtlist[[length(trtlist)+1]] <- list(names(trtnew)[i], trtnew[[i]][k])
-      }
-    }
-  }
-
-
   # Generate array of relative effects between all treatments in network
-  rel <- array(dim=c(length(trtlist), length(trtlist), mbnma$BUGSoutput$n.sims))
-  for (i in 1:length(trtlist)) {
-    for (k in 1:length(trtlist)) {
+  if ("mbnma" %in% class(lower.diag)) {
+    lower.nsims <- lower.diag$BUGSoutput$n.sims
+  } else {
+    lower.nsims <- lower.diag$jagsresult$BUGSoutput$n.sims
+  }
+  if ("mbnma" %in% class(upper.diag)) {
+    upper.nsims <- upper.diag$BUGSoutput$n.sims
+  } else {
+    upper.nsims <- upper.diag$jagsresult$BUGSoutput$n.sims
+  }
+  nsims <- min(lower.nsims, upper.nsims)
+  rel <- array(dim=c(length(unlist(treatments)), length(unlist(treatments)), nsims))
 
-      agnum.i <- which(mbnma$network$agents %in% trtlist[[i]][[1]])
-      agnum.k <- which(mbnma$network$agents %in% trtlist[[k]][[1]])
+  # Generate chunks of relative effects for each model and treatment comparison
+  for (mod in seq_along(modlist)) {
 
-      # Account for lack of placebo
-      if (!"Placebo_0" %in% mbnma$network$treatments & length(fun$name)==1) {
-        agnum.i <- agnum.i+1
-        agnum.k <- agnum.k+1
+    # For MBNMA models
+    if ("mbnma" %in% class(modlist[[mod]])) {
+
+      mbnma <- modlist[[mod]]
+
+      # Get regression parameter estimates and multiply by regress.vals
+      if (!is.null(regress.vals)) {
+        check.predreg(mbnma=mbnma, regress.vals=regress.vals)
+        regress <- get.regress.vals(mbnma, regress.vals, sum=TRUE)
       }
-      agnum <- c(agnum.i, agnum.k)
 
-      # For agent-specific dose-response functions
+      # Identify dose-response function used in mbnma
+      DR <- suppressMessages(
+        write.dose.fun(fun=mbnma$model.arg$fun, effect="abs")[[1]])
+      DR <- gsub("(^.+<-)(.+)", "\\2", DR)
+      DR <- gsub("s\\.", "", DR) # Could remove if needed
       if (length(mbnma$model.arg$fun$name)>1) {
-        posi <- mbnma$model.arg$fun$posvec[agnum.i]
-        tempDR1 <- DR[posi]
+        DR <- DR[-1]
+      }
 
-        posk <- mbnma$model.arg$fun$posvec[agnum.k]
-        tempDR2 <- DR[posk]
+      # Get dose-response parameter values
+      betaparams <- get.model.vals(mbnma)
 
-        pos <- c(posi, posk)
+      trtnew <- treatments
+
+      # Generate spline basis matrix if required
+      splineopt <- c("rcs", "bs", "ns", "ls")
+      fun <- mbnma$model.arg$fun
+
+      # Get indices of non-placebo agents
+      index <- match(names(trtnew), mbnma$network$agents[!mbnma$network$agents %in% "Placebo"])
+
+      # If there are multiple DR functions
+      if ("posvec" %in% names(fun)) {
+        posvec <- fun$posvec
+
+        # Remove 1st element if Placebo in network
+        if ("Placebo" %in% mbnma$network$agents) {
+          posvec <- posvec[-1]
+        }
       } else {
-        tempDR1 <- DR
-        tempDR2 <- DR
+        posvec <- rep(1, max(index))
+      }
+      for (i in seq_along(index)) {
+
+        if (fun$name[posvec[index[i]]] %in% splineopt) {
+          trtnew[[i]] <- genspline(trtnew[[i]],
+                                   spline = fun$name[posvec[index[i]]],
+                                   knots=fun$knots[[posvec[index[i]]]],
+                                   degree = fun$degree[posvec[index[i]]],
+                                   max.dose=max(mbnma$network$data.ab$dose[mbnma$network$data.ab$agent==which(names(trtnew)[i] == mbnma$network$agents)]))
+        }
       }
 
-      DR1 <- gsub("agent\\[i,k\\]", paste0(",", agnum.i-1), tempDR1)
-      DR1 <- gsub("dose\\[i,k\\]", trtlist[[i]][[2]][1], DR1)
-
-      DR2 <- gsub("agent\\[i,k\\]", paste0(",", agnum.k-1), tempDR2)
-      DR2 <- gsub("dose\\[i,k\\]", trtlist[[k]][[2]][1], DR2)
-
-      # Replace spline
-      for (m in 1:length(betaparams)) {
-        DR1 <- gsub(paste0("spline\\[i,k,", m, "\\]"), trtlist[[i]][[2]][m], DR1)
-        DR2 <- gsub(paste0("spline\\[i,k,", m, "\\]"), trtlist[[k]][[2]][m], DR2)
-      }
-
-      for (beta in seq_along(betaparams)) {
-        assign(names(betaparams)[beta], betaparams[[beta]])
-
-        if (length(mbnma$model.arg$fun$name)==1) {
-          if (!is.matrix(betaparams[[beta]])) {
-            DR1 <- gsub(paste0("(",names(betaparams)[beta], ")(\\[,[0-9]+\\])"), "\\1", DR1)
-            DR2 <- gsub(paste0("(",names(betaparams)[beta], ")(\\[,[0-9]+\\])"), "\\1", DR2)
+      # Create list of treatments with doses
+      trtlist <- list()
+      for (i in seq_along(trtnew)) {
+        if (is.matrix(trtnew[[i]])) { # Allows for splines
+          for (k in 1:nrow(trtnew[[i]])) {
+            trtlist[[length(trtlist)+1]] <- list(names(trtnew)[i], as.vector(trtnew[[i]][k,]))
           }
         } else {
-
-          if (is.matrix(betaparams[[beta]])) {
-
-            DRcomb <- c(DR1, DR2)
-            for (m in 1:2) {
-              # Look for correct column index for each beta param
-              veci <- mbnma$model.arg$fun$posvec[1:agnum[m]]
-              veci <- table(veci)[names(table(veci))==pos[m]]
-
-              if (names(veci)=="1") {
-                # Check if placebo in dataset
-                if (mbnma$network$agents[1]=="Placebo") {
-                  veci <- veci - 1
-                }
-              }
-
-              # Swap index in DR1 for veci
-              DRcomb[m] <- gsub(paste0("(", names(betaparams)[beta], "\\[,)([0-9]+\\])"),
-                          paste0("\\1", veci, "]"), DRcomb[m])
-            }
-            DR1 <- DRcomb[1]
-            DR2 <- DRcomb[2]
-
-          } else if (is.vector(betaparams[[beta]])) {
-            # Remove indices from DR
-            DR1 <- gsub(paste0("(", names(betaparams)[beta], ")(\\[,[0-9]+\\])"), "\\1", DR1)
-            DR2 <- gsub(paste0("(", names(betaparams)[beta], ")(\\[,[0-9]+\\])"), "\\1", DR2)
+          for (k in seq_along(trtnew[[i]])) {
+            trtlist[[length(trtlist)+1]] <- list(names(trtnew)[i], trtnew[[i]][k])
           }
         }
       }
 
-      chunk <- eval(parse(text=paste0("(",DR1, ") - (", DR2, ")")))
+      for (i in 1:(length(trtlist)-1)) {
+        for (k in (i+1):length(trtlist)) {
 
-      if (length(rel)<=1) {stop("length(rel)<=1")}
+          agnum.i <- which(mbnma$network$agents %in% trtlist[[i]][[1]])
+          agnum.k <- which(mbnma$network$agents %in% trtlist[[k]][[1]])
 
-      # Incorporate between-study SD
-      if (addsd==TRUE) {
-        mat <- matrix(nrow=length(chunk), ncol=2)
-        mat[,1] <- chunk
-        mat[,2] <- mbnma$BUGSoutput$sims.list[["sd"]]
-        chunk <- apply(mat, MARGIN=1, FUN=function(x) stats::rnorm(1, x[1], x[2]))
+          # Account for lack of placebo
+          if (!"Placebo_0" %in% mbnma$network$treatments & length(fun$name)==1) {
+            agnum.i <- agnum.i+1
+            agnum.k <- agnum.k+1
+          }
+          agnum <- c(agnum.i, agnum.k)
+
+          # For agent-specific dose-response functions
+          if (length(mbnma$model.arg$fun$name)>1) {
+            posi <- mbnma$model.arg$fun$posvec[agnum.i]
+            tempDR1 <- DR[posi]
+
+            posk <- mbnma$model.arg$fun$posvec[agnum.k]
+            tempDR2 <- DR[posk]
+
+            pos <- c(posi, posk)
+          } else {
+            tempDR1 <- DR
+            tempDR2 <- DR
+          }
+
+          DR1 <- gsub("agent\\[i,k\\]", paste0(",", agnum.i-1), tempDR1)
+          DR1 <- gsub("dose\\[i,k\\]", trtlist[[i]][[2]][1], DR1)
+
+          DR2 <- gsub("agent\\[i,k\\]", paste0(",", agnum.k-1), tempDR2)
+          DR2 <- gsub("dose\\[i,k\\]", trtlist[[k]][[2]][1], DR2)
+
+          # Replace spline
+          for (m in 1:length(betaparams)) {
+            DR1 <- gsub(paste0("spline\\[i,k,", m, "\\]"), trtlist[[i]][[2]][m], DR1)
+            DR2 <- gsub(paste0("spline\\[i,k,", m, "\\]"), trtlist[[k]][[2]][m], DR2)
+          }
+
+          for (beta in seq_along(betaparams)) {
+            assign(names(betaparams)[beta], betaparams[[beta]])
+
+            if (length(mbnma$model.arg$fun$name)==1) {
+              if (!is.matrix(betaparams[[beta]])) {
+                DR1 <- gsub(paste0("(",names(betaparams)[beta], ")(\\[,[0-9]+\\])"), "\\1", DR1)
+                DR2 <- gsub(paste0("(",names(betaparams)[beta], ")(\\[,[0-9]+\\])"), "\\1", DR2)
+              }
+            } else {
+
+              if (is.matrix(betaparams[[beta]])) {
+
+                DRcomb <- c(DR1, DR2)
+                for (m in 1:2) {
+                  # Look for correct column index for each beta param
+                  veci <- mbnma$model.arg$fun$posvec[1:agnum[m]]
+                  veci <- table(veci)[names(table(veci))==pos[m]]
+
+                  if (names(veci)=="1") {
+                    # Check if placebo in dataset
+                    if (mbnma$network$agents[1]=="Placebo") {
+                      veci <- veci - 1
+                    }
+                  }
+
+                  # Swap index in DR1 for veci
+                  DRcomb[m] <- gsub(paste0("(", names(betaparams)[beta], "\\[,)([0-9]+\\])"),
+                                    paste0("\\1", veci, "]"), DRcomb[m])
+                }
+                DR1 <- DRcomb[1]
+                DR2 <- DRcomb[2]
+
+              } else if (is.vector(betaparams[[beta]])) {
+                # Remove indices from DR
+                DR1 <- gsub(paste0("(", names(betaparams)[beta], ")(\\[,[0-9]+\\])"), "\\1", DR1)
+                DR2 <- gsub(paste0("(", names(betaparams)[beta], ")(\\[,[0-9]+\\])"), "\\1", DR2)
+              }
+            }
+          }
+
+          chunk <- eval(parse(text=paste0("(",DR1, ") - (", DR2, ")")))
+
+          if (!is.null(regress.vals)) {
+            chunk <- chunk + (regress[,agnum.i-1] - regress[,agnum.k-1])
+          }
+
+          if (length(rel)<=1) {stop("length(rel)<=1")}
+
+          # Incorporate between-study SD
+          if (addsd==TRUE) {
+            mat <- matrix(nrow=length(chunk), ncol=2)
+            mat[,1] <- chunk
+            mat[,2] <- stats::median(mbnma$BUGSoutput$sims.list[["sd"]])  # Use median to avoid MCMC error
+            chunk <- apply(mat, MARGIN=1, FUN=function(x) stats::rnorm(1, x[1], x[2]))
+          }
+
+          # Ensure length(chunk) matches nsims
+          if (length(chunk)!=nsims) {
+            chunk <- sample(chunk, size=nsims)
+          }
+
+          if (mod==2) {
+            rel[i,k,] <- chunk
+          } else if (mod==1) {
+            rel[k,i,] <- -chunk
+          } else {
+            stop("error in length(modlist)")
+          }
+        }
       }
 
-      rel[i,k,] <- chunk
-      rel[k,i,] <- -chunk
-      rel[i,i,] <- 0
-      rel[k,k,] <- 0
+      # For NMA models
+    } else if ("nma" %in% class(modlist[[mod]])) {
 
+      nma <- modlist[[mod]]
+
+      for (i in 1:(length(treatments.nma)-1)) {
+        for (k in (i+1):length(treatments.nma)) {
+          nmat.i <- which(nma$trt.labs %in% treatments.nma[i])
+          nmat.k <- which(nma$trt.labs %in% treatments.nma[k])
+
+          if (nma$UME==FALSE) {
+            chunk.nma <- nma$jagsresult$BUGSoutput$sims.list$d[,nmat.i] - nma$jagsresult$BUGSoutput$sims.list$d[,nmat.k]
+            skip <- FALSE
+          } else if (nma$UME==TRUE) {
+            chunk.nma <- nma$jagsresult$BUGSoutput$sims.list$d[,nmat.i,nmat.k]
+
+            if (sd(chunk.nma)>90) {
+              chunk.nma <- NA # No direct evidence
+              skip <- TRUE
+            } else {
+              skip <- FALSE
+            }
+          }
+
+          if (skip==FALSE) {
+            # Ensures NMA also uses prediction intervals (if method="random")
+            if (addsd==TRUE) {
+              if ("sd" %in% nma$jagsresult$parameters.to.save) {
+                chunk.nma <- apply(chunk.nma, MARGIN=1, FUN=function(x) stats::rnorm(1, x, nma$jagsresult$BUGSoutput$median$sd))
+              }
+            }
+
+            # Ensure length(chunk) matches nsims
+            if (length(chunk.nma)!=nsims) {
+              chunk.nma <- sample(chunk.nma, size=nsims)
+            }
+          }
+
+          if (mod==2) {
+            rel[i,k,] <- chunk.nma
+          } else if (mod==1) {
+            rel[k,i,] <- -chunk.nma
+          } else {
+            stop("error in length(modlist)")
+          }
+        }
+      }
+    }
+  }
+
+  # Set direction of effects
+  for (i in 1:(ncol(rel)-1)) {
+    for (k in (i+1):nrow(rel)) {
+      if (lower.direction=="rowvcol") {
+        rel[k,i,] <- -rel[k,i,]
+      }
+      if (upper.direction=="rowvcol") {
+        rel[i,k,] <- -rel[i,k,]
+      }
+      if (i==k) {
+        rel[i,k,] <- 0
+      }
     }
   }
 
@@ -1097,13 +1299,29 @@ get.relative <- function(mbnma, treatments=list(), eform=FALSE, lim="cred") {
 
   ######### Summary matrixes ######
 
-  xmat <- outmat
+  out <- mat.rel.sum(xmat=outmat, trtnames=trtnames)
+
+  attributes(out) <- list("class"="relative.array",
+                          "names"=names(out),
+                          "lim"=lim)
+
+  return(out)
+}
+
+
+
+
+#' Summarise relative array outputs for `get.relative()`
+#'
+#' @noRd
+mat.rel.sum <- function(xmat, trtnames) {
 
   meanmat <- matrix(nrow=nrow(xmat), ncol=ncol(xmat))
   semat <- meanmat
   medmat <- meanmat
   l95mat <- medmat
   u95mat <- medmat
+  sum.df <- data.frame(comparison=NA, mean=NA, sd=NA, l95=NA, med=NA, u95=NA)
 
   for (i in 1:nrow(xmat)) {
     for (k in 1:ncol(xmat)) {
@@ -1113,9 +1331,22 @@ get.relative <- function(mbnma, treatments=list(), eform=FALSE, lim="cred") {
         medmat[i,k] <- stats::median(xmat[i,k,])
         l95mat[i,k] <- stats::quantile(xmat[i,k,], probs = 0.025)
         u95mat[i,k] <- stats::quantile(xmat[i,k,], probs = 0.975)
+
+        if (k>i) {
+          sum.df <- dplyr::add_row(sum.df,
+                                   comparison = paste0(trtnames[i], " vs ", trtnames[k]),
+                                   mean=meanmat[i,k],
+                                   sd=semat[i,k],
+                                   l95=l95mat[i,k],
+                                   med=medmat[i,k],
+                                   u95=u95mat[i,k]
+          )
+        }
       }
     }
   }
+  sum.df <- sum.df[-1,]
+  names(sum.df) <- c("comparison", "mean", "sd", "2.5%", "50%", "97.5%")
 
   sumlist <- list("mean"=meanmat, "se"=semat, "median"=medmat, "lower95"=l95mat, "upper95"=u95mat)
 
@@ -1124,11 +1355,8 @@ get.relative <- function(mbnma, treatments=list(), eform=FALSE, lim="cred") {
     dimnames(sumlist[[i]])[[2]] <- dimnames(xmat)[[2]]
   }
 
-  out <- list("relarray"=outmat)
+  out <- list("data.frame"=sum.df, "relarray"=xmat)
   out <- c(out, sumlist)
-  out$lim <- lim
-
-  class(out) <- "relative.array"
 
   return(out)
 }
