@@ -68,7 +68,7 @@ test_that(paste("rank.functions work correctly"), {
 
       rank <- rank.mbnma(quad)
       expect_equal(names(rank), "beta.1")
-      expect_equal(names(rank[[1]]), c("summary", "prob.matrix", "rank.matrix", "cum.matrix", "lower_better"))
+      expect_equal(names(rank[[1]]), c("summary", "prob.matrix", "rank.matrix", "cum.matrix"))
       expect_equal(class(rank[[1]]$summary), "data.frame")
       expect_equal("matrix" %in% class(rank[[1]]$rank.matrix), TRUE)
       expect_equal("matrix" %in% class(rank[[1]]$prob.matrix), TRUE)
@@ -78,7 +78,7 @@ test_that(paste("rank.functions work correctly"), {
 
       rank <- rank.mbnma(emax)
       expect_equal(sort(names(rank)), sort(c("emax", "ed50")))
-      expect_equal(names(rank[[1]]), c("summary", "prob.matrix", "rank.matrix", "cum.matrix", "lower_better"))
+      expect_equal(names(rank[[1]]), c("summary", "prob.matrix", "rank.matrix", "cum.matrix"))
       expect_equal(class(rank[[2]]$summary), "data.frame")
       expect_equal("matrix" %in% class(rank[[1]]$rank.matrix), TRUE)
       expect_equal("matrix" %in% class(rank[[2]]$prob.matrix), TRUE)
@@ -144,7 +144,7 @@ test_that(paste("rank.functions work correctly"), {
       pred <- predict(quad, E0 = 0.5)
       rank <- rank.mbnma.predict(pred)
       expect_equal(names(rank), "Predictions")
-      expect_equal(names(rank$Predictions), c("summary", "prob.matrix", "rank.matrix", "lower_better"))
+      expect_equal(names(rank$Predictions), c("summary", "prob.matrix", "rank.matrix", "cum.matrix"))
       expect_equal(class(rank$Predictions$summary), "data.frame")
       expect_equal("matrix" %in% class(rank$Predictions$rank.matrix), TRUE)
       expect_equal("matrix" %in% class(rank$Predictions$prob.matrix), TRUE)
@@ -158,7 +158,7 @@ test_that(paste("rank.functions work correctly"), {
                       exact.doses=doses)
       rank <- rank.mbnma.predict(pred)
       expect_equal(names(rank), "Predictions")
-      expect_equal(names(rank$Predictions), c("summary", "prob.matrix", "rank.matrix", "lower_better"))
+      expect_equal(names(rank$Predictions), c("summary", "prob.matrix", "rank.matrix", "cum.matrix"))
       expect_equal(class(rank$Predictions$summary), "data.frame")
       expect_equal("matrix" %in% class(rank$Predictions$rank.matrix), TRUE)
       expect_equal("matrix" %in% class(rank$Predictions$prob.matrix), TRUE)
